pub fn classify_statements(statements: &[SqlStatement]) -> LintReportExpand description
Classify a set of SqlStatements and return a LintReport.
Deterministic; never panics. See the module docs for what is and is not detected.
pub fn classify_statements(statements: &[SqlStatement]) -> LintReportClassify a set of SqlStatements and return a LintReport.
Deterministic; never panics. See the module docs for what is and is not detected.