pub struct LintReport {
pub findings: Vec<Finding>,
pub statements: usize,
}Expand description
The aggregated lint report for a set of SQL statements.
Fields
findings: Vec<Finding>The findings, in statement order.
statements: usizeThe number of statements analyzed.
Implementations
Sourceimpl LintReport
impl LintReport
Sourcepub fn count_at(&self, severity: LintSeverity) -> usize
pub fn count_at(&self, severity: LintSeverity) -> usize
The count of findings at the given severity.
Sourcepub fn has_critical(&self) -> bool
pub fn has_critical(&self) -> bool
true when at least one critical finding is present.